isBuilder property
The member returns a WidgetBuilder (legal per Flutter's annotation)
rather than a Widget, so the mount wraps it in a Builder.
Implementation
final bool isBuilder;
The member returns a WidgetBuilder (legal per Flutter's annotation)
rather than a Widget, so the mount wraps it in a Builder.
final bool isBuilder;